@@ -25,7 +25,7 @@ __all__ = (
 )
 
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 
 
 def is_number(number):
@@ -498,8 +498,20 @@ class AbstractInterval(object):
                 other.lower_inc if other.lower > self.lower else self.lower_inc
             )
             intersection.upper_inc = other.upper_inc
+        else:
+            return other & self
         return intersection
 
+    def __or__(self, other):
+        """
+        Defines the union operator
+        """
+        if self.upper < other.lower or other.upper < self.lower:
+            raise IntervalException(
+                'Union is not continuous.'
+            )
+        return self.sup(other)
+
 
 class NumberInterval(AbstractInterval):
     def round_value_by_step(self, value):
